@@ -213,6 +213,11 @@ class Device(NMDbusInterface):
             NM_DEVICE_TYPE_ADSL: Adsl,
         }[self.DeviceType](self.object_path)
 
+    def postprocess(self, name, val):
+        if name == 'Ip4Address':
+            return fixups.addr_to_python(val)
+        return val
+
 class AccessPoint(NMDbusInterface):
     interface_name = 'org.freedesktop.NetworkManager.AccessPoint'
 
@@ -342,7 +347,7 @@ class fixups(object):
         addr, netmask, gateway = addrconf
         return [
             fixups.addr_to_dbus(addr),
-            netmask,
+            fixups.mask_to_dbus(netmask),
             fixups.addr_to_dbus(gateway)
         ]
 
@@ -352,7 +357,11 @@ class fixups(object):
 
     @staticmethod
     def addr_to_dbus(addr):
-        return struct.unpack('I', socket.inet_aton(addr))
+        return dbus.UInt32(struct.unpack('I', socket.inet_aton(addr))[0])
+
+    @staticmethod
+    def mask_to_dbus(mask):
+        return dbus.UInt32(mask)
 
     @staticmethod
     def route_to_python(route):
@@ -369,7 +378,7 @@ class fixups(object):
         addr, netmask, gateway, metric = route
         return [
             fixups.addr_to_dbus(addr),
-            netmask,
+            fixups.mask_to_dbus(netmask),
             fixups.addr_to_dbus(gateway),
             socket.htonl(metric)
         ]
